@@ -1,7 +1,7 @@
 use crate::{arrayvec::ArrayVec, len::LengthType, mem::SpareMemoryPolicy};
 use core::convert::AsRef;
 
-impl<T, L, SM, const C: usize> AsRef<[T]> for ArrayVec<T, L, SM, C>
+impl<T, L, SM, const C: usize> AsRef<[T]> for ArrayVec<T, C, L, SM>
 where
     L: LengthType,
     SM: SpareMemoryPolicy<T>,
@@ -12,13 +12,13 @@ where
     }
 }
 
-impl<T, L, SM, const C: usize> AsRef<ArrayVec<T, L, SM, C>> for ArrayVec<T, L, SM, C>
+impl<T, L, SM, const C: usize> AsRef<ArrayVec<T, C, L, SM>> for ArrayVec<T, C, L, SM>
 where
     L: LengthType,
     SM: SpareMemoryPolicy<T>,
 {
     #[inline]
-    fn as_ref(&self) -> &ArrayVec<T, L, SM, C> {
+    fn as_ref(&self) -> &Self {
         self
     }
 }
@@ -26,7 +26,7 @@ where
 #[cfg(test)]
 mod testing {
     use crate as cds;
-    use crate::{array_vec, arrayvec::ArrayVec, len::Usize, mem::Uninitialized};
+    use crate::{array_vec, arrayvec::ArrayVec};
     use core::convert::AsRef;
 
     #[test]
@@ -39,7 +39,7 @@ mod testing {
 
     #[test]
     fn test_as_ref_av() {
-        type A = ArrayVec<u64, Usize, Uninitialized, 3>;
+        type A = ArrayVec<u64, 3>;
         let a = A::try_from([1, 2, 3]).unwrap();
         let a_ref: &A = a.as_ref();
         assert_eq!((a_ref as *const A), (&a as *const A));
