@@ -5,3 +5,6 @@ pub use capacity_error::*;
 
 mod insert_error;
 pub use insert_error::*;
+
+mod index_error;
+pub use index_error::*;
